<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kbugbuster" version="11">

<MenuBar>
  <Menu name="file" noMerge="1"><text>&amp;File</text>
    <Action name="file_new_window" />
    <Action name="file_seechanges" />
    <Action name="file_submit" />
    <Separator/>
    <Action name="file_quit" />
  </Menu>
  <Menu name="view"><text>&amp;View</text>
    <Action name="reload_packagelist" />
    <Action name="reload_package" />
    <Action name="reload_bug" />
    <Separator/>
    <Action name="load_my_bugs" />
    <Action name="load_allbugs" />
    <Separator/>
    <Action name="extract_attachments" />
    <Separator/>
    <Action name="clear_cache" />
    <Separator/>
    <Action name="debug_lastresponse" />
    <Action name="debug_showbugsource" />
  </Menu>
  <Menu name="search"><text>S&amp;earch</text>
    <Action name="search_package" />
    <Action name="search_bugnumber" />
    <Action name="search_description" />
  </Menu>
  <Action name="bookmarks"/>
  <Menu name="commands"><text>&amp;Commands</text>
  <!--  <Action name="cmd_merge" />
    <Action name="cmd_unmerge" />
    <Separator/> -->
    <Action name="cmd_close" />
    <Action name="cmd_close_silently" />
    <Action name="cmd_reopen" />
    <Action name="cmd_reassign" />
    <Action name="cmd_title" />
    <Action name="cmd_severity" />
    <Separator/>
    <Action name="cmd_reply" />
    <Action name="cmd_replyprivate" />
  </Menu>
  <Menu name="settings"><text>&amp;Settings</text>
    <Action name="settings_disconnected" append="save_merge"/>
    <Action name="select_server" append="save_merge"/>
  </Menu>
</MenuBar>

<ToolBar name="searchToolBar"><text>Search Toolbar</text>
    <Action name="search_package" />
    <Action name="search_bugnumber" />
    <Action name="search_description" />
</ToolBar>

<ToolBar name="commandToolBar"><text>Command Toolbar</text>
    <Action name="cmd_merge" />
    <Action name="cmd_unmerge" />
    <Separator/>
    <Action name="cmd_close" />
    <Action name="cmd_reopen" />
    <Action name="cmd_reassign" />
    <Action name="cmd_title" />
    <Action name="cmd_severity" />
    <Separator/>
    <Action name="cmd_reply" />
    <Action name="cmd_replyprivate" />
</ToolBar>

<ToolBar name="settingToolBar"><text>Settings Toolbar</text>
    <Action name="cmd_toggle_wishes" />
    <Action name="cmd_toggle_done" />
</ToolBar>

</kpartgui>
