<!DOCTYPE kpartgui>
<kpartgui name="catalogmanager" version="26">
 <MenuBar>
   <Menu name="edit"><text>&amp;Edit</text>
      <Action name="find_in_files"/>
      <Action name="replace_in_files"/>
      <Action name="stop_search"/>
      <Separator/>
      <Action name="reload"/>
   </Menu>
   <Menu name="go"><text>&amp;Go</text>
      <Action name="go_next_fuzzyUntr"/>
      <Action name="go_prev_fuzzyUntr"/>
      <Action name="go_next_fuzzy"/>
      <Action name="go_prev_fuzzy"/>
      <Action name="go_next_untrans"/>
      <Action name="go_prev_untrans"/>
      <Separator/>
      <Action name="go_next_error"/>
      <Action name="go_prev_error"/>
      <Separator/>
      <Action name="go_next_marked"/>
      <Action name="go_prev_marked"/>
      <Separator/>
      <Action name="go_next_template"/>
      <Action name="go_prev_template"/>
      <Action name="go_next_po"/>
      <Action name="go_prev_po"/>
   </Menu>
   <Menu name="markings"><text>&amp;Markings</text>
      <Action name="toggle_marking"/>
      <Action name="remove_marking"/>
      <Action name="toggle_all_marking"/>
      <Action name="remove_all_marking"/>
      <Action name="mark_modified_files"/>
      <Separator/>
      <Action name="mark_pattern"/>
      <Action name="unmark_pattern"/>
      <Separator/>
      <Action name="load_marking"/>
      <Action name="save_marking"/>
   </Menu>
   <Menu name="projects"><text>&amp;Project</text>
    <Action name="project_new"/>
    <Action name="project_open"/>
    <Action name="project_close"/>
    <Action name="project_settings"/>
   </Menu>
   <Menu name="tools"><text>&amp;Tools</text>
      <Action name="statistics"/>
      <Action name="statistics_marked"/>
      <Action name="syntax"/>
      <Separator/>
      <Action name="spellcheck"/>
      <Action name="spellcheck_marked"/>
      <Separator/>
      <Action name="rough_translation"/>
      <Action name="rough_translation_marked"/>
      <Separator/>
        <Menu name="cvs_menu"><text>CVS</text>
          <Action name="cvs_update"/>
          <Action name="cvs_update_marked"/>
          <Separator/>
          <Action name="cvs_commit"/>
          <Action name="cvs_commit_marked"/>
          <Separator/>
          <Action name="cvs_status"/>
          <Action name="cvs_status_marked"/>
          <Separator/>
          <Action name="cvs_update_template"/>
          <Action name="cvs_update_marked_template"/>
          <Separator/>
          <Action name="cvs_commit_template"/>
          <Action name="cvs_commit_marked_template"/>
          <Separator/>
          <Action name="cvs_diff"/>
        </Menu>
        <Menu name="svn_menu"><text>SVN</text>
            <Action name="svn_update"/>
            <Action name="svn_update_marked"/>
            <Separator/>
            <Action name="svn_commit"/>
            <Action name="svn_commit_marked"/>
            <Separator/>
            <Action name="svn_status_local"/>
            <Action name="svn_status_local_marked"/>
            <Separator/>
            <Action name="svn_status_remote"/>
            <Action name="svn_status_remote_marked"/>
            <Separator/>
            <Action name="svn_update_template"/>
            <Action name="svn_update_marked_template"/>
            <Separator/>
            <Action name="svn_commit_template"/>
            <Action name="svn_commit_marked_template"/>
            <Separator/>
            <Action name="svn_diff"/>
            <Separator/>
            <Action name="svn_info"/>
            <Action name="svn_info_marked"/>
        </Menu>
      <Separator/>
      <Action name="mail_file"/>
      <Action name="mail_file_marked"/>
      <Separaator/>
      <Action name="package_file"/>
      <Action name="package_file_marked"/>
      <Separator/>
      <Action name="dynamic_validation"/>
      <Action name="dynamic_validation_marked"/>
    </Menu>
   <Menu name="settings"><text>&amp;Settings</text>
      <Action name="settings_show_navbar" append="show_merge"/>
      <Action name="settings_show_comments" append="show_merge"/>
      <Action name="settings_show_tools" append="show_merge"/>
   </Menu>
   <Menu name="help"><text>&amp;Help</text>
      <Action name="help_gettext"/>
      <Action name="dict_about" append="about_merge"/>
   </Menu>
 </MenuBar>
 <ToolBar name="mainToolBar"><text>Main</text>
    <Action name="reload"/>
    <Action name="statistics"/>
    <Action name="syntax"/>
    <Action name="stop_search"/>
 </ToolBar>
 <ToolBar name="navigationbar"><text>Navigationbar</text>
    <Action name="go_prev_entry"/>
    <Action name="go_next_entry"/>
    <Separator/>
    <Action name="go_first"/>
    <Action name="go_last"/>
    <Action name="go_prev_fuzzyUntr"/>
    <Action name="go_next_fuzzyUntr"/>
    <Action name="go_prev_fuzzy"/>
    <Action name="go_next_fuzzy"/>
    <Action name="go_prev_untrans"/>
    <Action name="go_next_untrans"/>
    <Separator/>
    <Action name="go_prev_error"/>
    <Action name="go_next_error"/>
    <Separator/>
    <Action name="go_prev_marked"/>
    <Action name="go_next_marked"/>
    <Separator/>
    <Action name="go_prev_template"/>
    <Action name="go_next_template"/>
    <Action name="go_prev_po"/>
    <Action name="go_next_po"/>
 </ToolBar>
 <Menu name="rmb_file">
    <Action name="open"/>
    <Action name="open_new_window"/>
    <Action name="open_template"/>
    <Action name="toggle_marking"/>
    <Separator/>
    <Action name="reload"/>
    <Separator/>
    <Action name="syntax"/>
    <Action name="statistics"/>
    <Action name="dynamic_validation"/>
    <Action name="file_commands"/>
    <Separator/>
    <Menu name="rmb_file_cvs"><text>CVS</text>
      <Action name="cvs_update"/>
      <Action name="cvs_commit"/>
      <Action name="cvs_status"/>
      <Separator/>
      <Action name="cvs_update_template"/>
      <Action name="cvs_commit_template"/>
      <Separator/>
      <Action name="cvs_diff"/>
    </Menu>
    <Menu name="rmb_file_svn"><text>SVN</text>
      <Action name="svn_update"/>
      <Action name="svn_commit"/>
      <Action name="svn_status_local"/>
      <Action name="svn_status_remote"/>
      <Separator/>
      <Action name="svn_update_template"/>
      <Action name="svn_commit_template"/>
      <Separator/>
      <Action name="svn_diff"/>
    </Menu>
    <Separator/>
    <Action name="delete"/>
 </Menu>
 <Menu name="rmb_dir">
    <Action name="toggle_marking"/>
    <Action name="remove_marking"/>
    <Action name="toggle_all_marking"/>
    <Action name="remove_all_marking"/>
    <Separator/>
    <Action name="reload"/>
    <Separator/>
    <Action name="syntax"/>
    <Action name="statistics"/>
    <Action name="dynamic_validation"/>
    <Action name="dir_commands"/>
    <Separator/>
    <Menu name="rmb_dir_cvs"><text>CVS</text>
      <Action name="cvs_update"/>
      <Action name="cvs_commit"/>
      <Action name="cvs_status"/>
      <Separator/>
      <Action name="cvs_update_template"/>
      <Action name="cvs_commit_template"/>
      <Separator/>
      <Action name="cvs_diff"/>
    </Menu>
    <Menu name="rmb_dir_svn"><text>SVN</text>
      <Action name="svn_update"/>
      <Action name="svn_commit"/>
      <Action name="svn_status_local"/>
      <Action name="svn_status_remote"/>
      <Separator/>
      <Action name="svn_update_template"/>
      <Action name="svn_commit_template"/>
      <Separator/>
      <Action name="svn_diff"/>
    </Menu>
 </Menu>

<State name="treeBuilt">
    <Enable>
      <Action name="open"/>
      <Action name="open_new_window"/>
      <Action name="find_in_files"/>
      <Action name="replace_in_files"/>
      <Action name="reload"/>

      <Action name="go_next_fuzzyUntr"/>
      <Action name="go_prev_fuzzyUntr"/>
      <Action name="go_next_fuzzy"/>
      <Action name="go_prev_fuzzy"/>
      <Action name="go_next_untrans"/>
      <Action name="go_prev_untrans"/>
      <Action name="go_next_error"/>
      <Action name="go_prev_error"/>
      <Action name="go_next_marked"/>
      <Action name="go_prev_marked"/>
      <Action name="go_next_template"/>
      <Action name="go_prev_template"/>
      <Action name="go_next_po"/>
      <Action name="go_prev_po"/>
      <Action name="load_marking"/>
      <Action name="save_marking"/>
      <Action name="toggle_marking"/>
      <Action name="toggle_all_marking"/>
      <Action name="statistics"/>
      <Action name="rough_translation"/>
      <Action name="reload"/>
      <Action name="dynamic_validation"/>
      <Action name="dynamic_validation_marked"/>
      <Action name="mail_file"/>
      <Action name="mark_pattern"/>
      <Action name="unmark_pattern"/>
    </Enable>
</State>

</kpartgui>
