/****************************************************************************
**
** DCOP Stub Definition created by dcopidl2cpp from repository.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#ifndef __REPOSITORY_STUB__
#define __REPOSITORY_STUB__

#include <dcopstub.h>
#include <dcopobject.h>
#include <qobject.h>


class KDE_EXPORT Repository_stub : virtual public DCOPStub
{
public:
    Repository_stub( const QCString& app, const QCString& id );
    Repository_stub( DCOPClient* client, const QCString& app, const QCString& id );
    explicit Repository_stub( const DCOPRef& ref );
    virtual bool setWorkingCopy( const QString& dirName );
    virtual QString workingCopy();
    virtual QString location();
    virtual bool retrieveCvsignoreFile();
protected:
    Repository_stub() : DCOPStub( never_use ) {}
};


#endif
