( cd usr/lib ; rm -rf libkbabelcommon.so )
( cd usr/lib ; ln -sf libkbabelcommon.so.3.2.0 libkbabelcommon.so )
( cd usr/lib ; rm -rf libkspy.so.1 )
( cd usr/lib ; ln -sf libkspy.so.1.2.0 libkspy.so.1 )
( cd usr/lib ; rm -rf libkompareinterface.so.0 )
( cd usr/lib ; ln -sf libkompareinterface.so.0.0.0 libkompareinterface.so.0 )
( cd usr/lib ; rm -rf libcvsservice.so.0 )
( cd usr/lib ; ln -sf libcvsservice.so.0.0.1 libcvsservice.so.0 )
( cd usr/lib ; rm -rf libcvsservice.so )
( cd usr/lib ; ln -sf libcvsservice.so.0.0.1 libcvsservice.so )
( cd usr/lib ; rm -rf libkunittestgui.so )
( cd usr/lib ; ln -sf libkunittestgui.so.0.0.0 libkunittestgui.so )
( cd usr/lib ; rm -rf libkunittestgui.so.0 )
( cd usr/lib ; ln -sf libkunittestgui.so.0.0.0 libkunittestgui.so.0 )
( cd usr/lib ; rm -rf libkompareinterface.so )
( cd usr/lib ; ln -sf libkompareinterface.so.0.0.0 libkompareinterface.so )
( cd usr/lib ; rm -rf libkbabeldictplugin.so )
( cd usr/lib ; ln -sf libkbabeldictplugin.so.1.2.0 libkbabeldictplugin.so )
( cd usr/lib ; rm -rf libkbabeldictplugin.so.1 )
( cd usr/lib ; ln -sf libkbabeldictplugin.so.1.2.0 libkbabeldictplugin.so.1 )
( cd usr/lib ; rm -rf libkbabelcommon.so.3 )
( cd usr/lib ; ln -sf libkbabelcommon.so.3.2.0 libkbabelcommon.so.3 )
( cd usr/lib ; rm -rf libkspy.so )
( cd usr/lib ; ln -sf libkspy.so.1.2.0 libkspy.so )
( cd usr/share/doc/HTML/en/cervisia ; rm -rf common )
( cd usr/share/doc/HTML/en/cervisia ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kompare ; rm -rf common )
( cd usr/share/doc/HTML/en/kompare ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kcachegrind ; rm -rf common )
( cd usr/share/doc/HTML/en/kcachegrind ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdesvn-build ; rm -rf common )
( cd usr/share/doc/HTML/en/kdesvn-build ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kbugbuster ; rm -rf common )
( cd usr/share/doc/HTML/en/kbugbuster ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kbabel ; rm -rf common )
( cd usr/share/doc/HTML/en/kbabel ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/umbrello ; rm -rf common )
( cd usr/share/doc/HTML/en/umbrello ; ln -sf /usr/share/doc/HTML/en/common common )
