echo "Creating $LOCATION_ROOT/${APP_NAME_LC}/${APP_NAME_LC}_part.rc...";
cat << EOF > $LOCATION_ROOT/${APP_NAME_LC}/${APP_NAME_LC}_part.rc
<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="${APP_NAME_LC}_part" version="1">
<MenuBar>
  <Menu name="file">
    <Action name="file_save"/>
    <Action name="file_save_as"/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar">
  <Action name="file_open"/>
  <Action name="file_save"/>
  <Action name="file_print"/>
  <Separator/>
</ToolBar>
</kpartgui>
