<!DOCTYPE kpartgui>
<kpartgui name="umbrello" version="11">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
      <Menu name="file_export"><text>&amp;Export</text>
          <Action name="file_export_docbook"/>
          <Action name="file_export_xhtml"/>
      </Menu>
  </Menu>
  <Menu name="edit"><text>&amp;Edit</text>
    <Action name="delete_selected"/>
  </Menu>
  <Menu name="views"><text>&amp;Diagram</text>
    <Menu name="new_view"><text>&amp;New</text>
      <Action name="new_class_diagram"/>
      <Action name="new_sequence_diagram"/>
      <Action name="new_collaboration_diagram"/>
      <Action name="new_use_case_diagram"/>
      <Action name="new_state_diagram"/>
      <Action name="new_activity_diagram"/>
      <Action name="new_component_diagram"/>
      <Action name="new_deployment_diagram"/>
      <Action name="new_entityrelationship_diagram"/>
    </Menu>
    <Action name="view_clear_diagram"/>
    <Action name="view_delete"/>
    <Action name="view_export_image"/>
    <Action name="view_export_image_all"/>
    <Action name="autolayout" />
    <Separator/>
    <Menu name="show_view"><text>Sh&amp;ow</text>
      <ActionList name="view_list">
      </ActionList>
    </Menu>
    <Menu name="zoom_menu"><text>&amp;Zoom</text>
    </Menu>
    <Separator/>
    <Action name="view_snap_to_grid"/>
    <Action name="view_show_grid"/>
    <Action name="view_properties"/>
  </Menu>

  <Menu name="code"><text>&amp;Code</text>
    <Action name="import_class"/>
    <Action name="generation_wizard"/>
    <Action name="generate_all"/>
    <Menu name="active_lang_menu"><text>Active &amp;Language</text>
    </Menu>
    <Separator/>
    <Action name="create_default_datatypes"/>
    <Action name="class_wizard"/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar">
  <Action name="popup_zoom"/>
  <Action name="zoom100"/>
</ToolBar>
</kpartgui>
