<!DOCTYPE kpartgui>
<kpartgui name="kbabel" version="21">
 <MenuBar>
   <Menu name="file"><text>&amp;File</text>
      <Action name="save_special" append="save_merge"/>
      <Action name="set_package" append="open_merge"/>
      <Action name="file_new_view"/>
      <Action name="file_new_window"/>
   </Menu>
   <Menu name="edit"><text>&amp;Edit</text>
      <Action name="clear"/>
      <Action name="msgid2msgstr"/>
      <Action name="search2msgstr"/>
      <Action name="plural2msgstr"/>
      <Action name="char2msgstr"/>
      <Action name="edit_toggle_fuzzy"/>
      <Separator/>
      <Action name="insert_next_tag"/>
      <Action name="insert_next_tag_msgid"/>
      <Action name="insert_tag"/>
      <Action name="move_to_next_tag"/>
      <Action name="move_to_prev_tag"/>
      <Separator/>
      <Action name="insert_next_arg"/>
      <Action name="insert_arg"/>
      <Separator/>
      <Action name="edit_edit_header"/>
   </Menu>
   <Menu noMerge="1" name="go_document"><text>&amp;Go</text>
      <Action name="go_prev_entry"/>
      <Action name="go_next_entry"/>
      <Action name="go_goto"/>
      <Separator/>
      <Action name="go_first"/>
      <Action name="go_last"/>
      <Separator/>
      <Action name="go_prev_fuzzyUntr"/>
      <Action name="go_next_fuzzyUntr"/>
      <Action name="go_prev_fuzzy"/>
      <Action name="go_next_fuzzy"/>
      <Action name="go_prev_untrans"/>
      <Action name="go_next_untrans"/>
      <Separator/>
      <Action name="go_prev_error"/>
      <Action name="go_next_error"/>
      <Separator/>
      <Action name="go_back_history"/>
      <Action name="go_forward_history"/>
   </Menu>
   <Menu name="projects"><text>&amp;Project</text>
    <Action name="project_new"/>
    <Action name="project_open"/>
    <Action name="project_close"/>
    <Action name="project_settings"/>
    <Action name="recent_projects"/>
   </Menu>
   <Menu name="tools"><text>&amp;Tools</text>
    <Menu name="spellcheck" icon="spellcheck"><text>&amp;Spelling</text>
	<Action name="spellcheck_common"/>
	<Separator/>
	<Action name="spellcheck_all"/>
	<Action name="spellcheck_from_cursor"/>
	<Action name="spellcheck_current"/>
	<Action name="spellcheck_from_current" />
	<Action name="spellcheck_marked"/>
    </Menu>
    <Action name="dynamic_validation_tools"/>
    <Menu name="diff" icon="diff"><text>D&amp;iff</text>
        <Action name="diff_diff"/>
        <Action name="diff_showOrig"/>
        <Action name="diff_openFile"/>
        <Separator/>
        <Action name="diff_toggleDiff"/>
    </Menu>
    <Action name="dynamic_modify_tools"/>
    <Separator/>
    <Action name="rough_translation"/>
    <Action name="word_count"/>
    <Separator/>
    <Action name="open_catalog_manager"/>
   </Menu>
   <Menu name="dictionaries"><text>&amp;Dictionaries</text>
    <Action name="dict_search_all"/>
    <Action name="dict_search_selected"/>
    <Action name="dict_edit"/>
   </Menu>
   <Menu name="settings"><text>&amp;Settings</text>
   <Action name="dict_configure" append="configure_merge"/>
   </Menu>
   <Menu name="bookmark"><text>&amp;Bookmarks</text>
    <Action name="add_bookmark"/>
    <Action name="clear_bookmarks"/>
    <Separator/>
   </Menu>
   <Menu name="help"><text>&amp;Help</text>
   <Action name="help_gettext"/>
   <Action name="dict_about" append="about_merge"/>
   </Menu>
 </MenuBar>
 <ToolBar name="mainToolBar"><text>Main</text>
    <Action name="msgid2msgstr"/>
    <Action name="search2msgstr"/>
    <Action name="insert_tag"/>
    <Action name="insert_arg"/>
    <Separator/>
    <Action name="spellcheck_common"/>
    <Action name="diff_toggleDiff"/>
    <Action name="dict_search_selected"/>
    <Action name="stop_search"/>
    <Separator/>
    <Action name="open_catalog_manager"/>
 </ToolBar>
 <ToolBar name="navigationbar"><text>Navigationbar</text>
   <Action name="go_prev_entry"/>
   <Action name="go_next_entry"/>
   <Separator/>
   <Action name="go_first"/>
   <Action name="go_last"/>
   <Action name="go_prev_fuzzyUntr"/>
   <Action name="go_next_fuzzyUntr"/>
   <Action name="go_prev_fuzzy"/>
   <Action name="go_next_fuzzy"/>
   <Action name="go_prev_untrans"/>
   <Action name="go_next_untrans"/>
   <Separator/>
   <Action name="go_prev_error"/>
   <Action name="go_next_error"/>
   <Separator/>
   <Action name="go_back_history"/>
   <Action name="go_forward_history"/>
 </ToolBar>
 <Menu name="rmb_edit">
    <Action name="edit_undo"/>
    <Action name="edit_redo"/>
    <Separator/>
    <Action name="edit_cut"/>
    <Action name="edit_copy"/>
	<Action name="edit_paste"/>
	<Action name="edit_select_all"/>
    <Separator/>
    <Action name="msgid2msgstr"/>
    <Action name="search2msgstr"/>
    <Action name="edit_unset_fuzzy"/>
    <Separator/>
    <Action name="insert_next_tag"/>
    <Action name="insert_tag"/>
	<Separator/>
    <Action name="dict_search_all"/>
    <Action name="dict_search_selected"/>
 </Menu>
 <Menu name="rmb_search">
    <Action name="edit_copy"/>
    <Action name="search2msgstr"/>
	<Separator/>
        <Action name="dict_search_all"/>
        <Action name="dict_search_selected"/>
	<Separator/>
        <Action name="dict_edit"/>
        <Action name="dict_configure"/>
	<Separator/>
	<Action name="stop_search"/>
 </Menu>
 <State name="readonly">
    <Disable>
    <Action name="file_save"/>
    <Action name="file_revert"/>
    <Action name="edit_undo"/>
    <Action name="edit_redo"/>
    <Action name="edit_cut"/>
    <Action name="edit_copy"/>
    <Action name="edit_paste"/>
    <Action name="edit_replace"/>
    <Action name="insert_next_tag"/>
    <Action name="insert_next_tag_msgid"/>
    <Action name="insert_tag"/>
    <Action name="insert_next_arg"/>
    <Action name="insert_arg"/>
    <Action name="plural2msgstr"/>
    <Action name="char2msgstr"/>
    <Action name="clear"/>
    <Action name="msgid2msgstr"/>
    <Action name="search2msgstr"/>
    <Action name="edit_edit_header"/>
    <Action name="edit_toggle_fuzzy"/>
    <Action name="spellcheck_common"/>
    <Action name="spellcheck_all"/>
    <Action name="spellcheck_from_cursor"/>
    <Action name="spellcheck_current"/>
    <Action name="spellcheck_from_current" />
    <Action name="spellcheck_marked"/>
    <Action name="rough_translation"/>
    </Disable>
 </State>
 <State name="fileopened">
    <Enable>
    <Action name="file_save_as"/>
    <Action name="save_special"/>
    <Action name="set_package"/>
    <Action name="file_mail"/>
    <Action name="edit_find"/>
    <Action name="edit_find_next"/>
    <Action name="edit_find_last"/>
    <Action name="edit_select_all"/>
    <Action name="move_to_next_tag"/>
    <Action name="move_to_prev_tag"/>
    <Action name="go_goto"/>
   <Action name="go_prev_entry"/>
   <Action name="go_next_entry"/>
   <Action name="go_first"/>
   <Action name="go_last"/>
   <Action name="go_prev_fuzzyUntr"/>
   <Action name="go_next_fuzzyUntr"/>
   <Action name="go_prev_fuzzy"/>
   <Action name="go_next_fuzzy"/>
   <Action name="go_prev_untrans"/>
   <Action name="go_next_untrans"/>
   <Action name="go_prev_error"/>
   <Action name="go_next_error"/>
   <Action name="go_back_history"/>
   <Action name="go_forward_history"/>
    <Action name="dict_search_selected"/>
    <Action name="dict_search_all"/>
    <Action name="diff_toggleDiff"/>
    <Action name="diff_diff"/>
    <Action name="diff_showOrig"/>
    <Action name="diff_openFile"/>
    <Action name="check_syntax"/>
    <Action name="check_all"/>
    <Action name="dynamic_validation_tools"/>
    <Action name="dynamic_modify_tools"/>
    <Action name="add_bookmark"/>
    <Action name="word_found"/>
    </Enable>
 </State>
</kpartgui>
