/****************************************************************************
**
** DCOP Stub Definition created by dcopidl2cpp from cvsjob.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#ifndef __CVSJOB_STUB__
#define __CVSJOB_STUB__

#include <dcopstub.h>
#include <dcopobject.h>
#include <qstringlist.h>
#include <qstring.h>
#include <qobject.h>


class KDE_EXPORT CvsJob_stub : virtual public DCOPStub
{
public:
    CvsJob_stub( const QCString& app, const QCString& id );
    CvsJob_stub( DCOPClient* client, const QCString& app, const QCString& id );
    explicit CvsJob_stub( const DCOPRef& ref );
    virtual bool execute();
    virtual void cancel();
    virtual bool isRunning();
    virtual QString cvsCommand();
    virtual QStringList output();
protected:
    CvsJob_stub() : DCOPStub( never_use ) {}
};


#endif
